@@ -147,13 +147,19 @@ class Channel:
             If False, a single figure will be shown.
         """
         # cant plot time over time
-        if self.isTime and self.verbose:
-            print("\t[ APREAD/PLOT ] Channel is time. Not plotting.")
+        if self.isTime:
+            if self.verbose:
+                print("\t[ APREAD/PLOT ] Channel is time. Not plotting.")
             return
 
+        if self.Time is None:
+            print("\t[ APREAD/PLOT ] Channel does not have time data. Not plotting.")
+            return
+
+        
         if self.verbose:
             print(f'\t[ APREAD/PLOT ] Filtering plot for {self.Name}')
-
+        
         # filter data
         datay = sig.wiener(self.data)
 
@@ -250,7 +256,7 @@ class Channel:
         if mode == 'csv':
             # write content to file
             for i in tqdm(range(length), desc=f'Create CSV: {self.Name}'):
-                content += (f'{self.Time.data[i]}\t{self.data[i]}\n')
+                content += (f'{self.Time.data[i] if self.Time is not None else ""}\t{self.data[i]}\n')
             if self.verbose:
                 print(f'\t☑ [ {self.fullName} → CSV ].')
 
@@ -258,7 +264,7 @@ class Channel:
             # write content to file
             
             data = {}
-            data['X'] = self.Time.data
+            if self.Time is not None: data['X'] = self.Time.data
             data['Y'] = self.data
             
             # output json
@@ -313,10 +319,11 @@ class Group:
         timeC = next((x for x in channels if x.isTime), None)
         self.ChannelX = timeC
 
-        if timeC is None and self.verbose:
+        if timeC is None:
             # if no time found, group cant be shown
-            print('\t[ APREAD/WARNING ] Group does not have a time-channel. Skipping...')
-        else:
+            if self.verbose:
+                print('\t[ APREAD/WARNING ] Group does not have a time-channel. Skipping...')
+        elif timeC is not None:
             # get name of time channel
             self.Name = timeC.Name
 
@@ -386,10 +393,7 @@ class Group:
             mode (str): 'csv' or 'json'
             path (str): the destination directory(!) path
         """
-        # get total length
-        length = len(self.ChannelX.data)
-        length1 = len(self.ChannelsY)
-
+        
         # ensure destination exists
         dest = os.path.join(path, self.fullName + f'.{mode}')
 
@@ -420,10 +424,10 @@ class Group:
         Returns:
             A formatted string representing this group in the specified mode.
         """
-        # get total length
-        length = len(self.ChannelX.data)
         # get length of y-channels
         length_x = len(self.ChannelsY)
+        # get total length
+        length = len(self.ChannelX.data) if self.ChannelX is not None else (len(self.ChannelsY[0]) if length_x > 0 else 0)
 
         # start with empty content
         content = ""
@@ -449,7 +453,8 @@ class Group:
 
             # create dummy dictionary to save as json
             data = {}
-            data['X'] = self.ChannelX.data
+            if self.ChannelX is not None:
+                data['X'] = self.ChannelX.data
             # add y-data to dict
             for j in range(length_x):
                 data[f'Y{j}'] = self.ChannelsY[j].data
